Learn R Programming

bayesTFR (version 1.2-0)

bayesTFR.mcmc.meta: MCMC Simulation Meta Object

Description

Simulation meta object bayesTFR.mcmc.meta used by all chains of the same MCMC simulation. It contains information that is common to all chains. It is part of a bayesTFR.mcmc.set object.

Arguments

Value

A bayesTFR.mcmc.meta object contains components U.width, U.c.low, U.up, a.width, a.low, a.up, b.width, b.low, b.up, const.width, const.low, const.up, S.width, S.low, S.up, sigma0.width, sigma0.low, sigma0.up, sigma0.min, mean.eps.tau0, sd.eps.tau0, nu.tau0, d.low, d.up, Triangle4.0, delta4.0, nu4, Triangle_c4.low, Triangle_c4.up, Triangle_c4.trans.width, chi0, nu.psi0, psi0, d.trans.width, dl.p1, dl.p2, nu.delta0, delta0, alpha0.p, start.year, present.year, wpp.year, buffer.size, auto.conf. Their meaning and value are the same as the input arguments to the run.tfr.mcmc function. Furthermore, it contains components:nr.chainsNumber of MCMC chains.tfr_matrix_allA $q \times n$ matrix with the United Nations TFR estimates. $q$ is number of years (see T_end below), $n$ is number of countries (see nr_countries below). The first $n_e$ columns correspond to countries included in the MCMC estimation (see nr_countries_estimation below), where $n_e <= n$.<="" description="">tfr_matrixLike tfr_matrix_all, but it has NA values before and after country's fertility transition.tfr_matrix_observedLike tfr_matrix, but it has NA values for years where no historical data is available.nr_countriesNumber of countries included in the tfr matrices.nr_countries_estimationNumber of countries included in the MCMC estimation. It must be smaller or equal to nr_countries.tau_cEstimated start year of the fertility decline for each country (as a row index within the tfr matrices). -1 means that the decline started before start.year.id_TistauIndex of countries for which present.year is equal to tau_c.id_DLIndex of countries for which the projection is made using the double logistic function, i.e. high fertility countries.id_earlyIndex of countries with early decline, i.e. countries for which tau_c=-1.id_notearlyIndex of countries with not early decline.lambda_cStart period of the recovery phase for each country (as an index of the tfr_matrix).start_cMaximum of tau_c and 1 for each country. Thus, it is a row index of the tfr_matrix where the fertility decline starts.proposal_cov_gammas_ciiProposal covariance matrices of $\gamma_{ci}$ for each country.T_endNumber of years for which United Nations historical data are available (i.e. number of rows of tfr_matrix).T_end_cLike T_end but country specific.regionsList of arrays of length nr_countries. These are: name - Region name for each country. code - Region code for each country. area_name - Area name for each country. area_code - Area code for each country. country_name - Array of country names. country_code - Array of country codes. Any country indices in the bayesTFR.mcmc.meta object are derived from this component.output.dirDirectory for storing simulation output.

Rdversion

1.1

Details

The object is in standard cases not to be manipulated by itself, but rather as part of a bayesTFR.mcmc.set object.

See Also

run.tfr.mcmc, get.tfr.mcmc

Examples

Run this code
sim.dir <- file.path(.find.package("bayesTFR"), "ex-data", 'bayesTFR.output')
m <- get.tfr.mcmc(sim.dir)
summary(m, meta.only = TRUE)
names(m$meta)

Run the code above in your browser using DataLab