Learn R Programming

bayesTFR (version 2.1-0)

coda.list.mcmc: Convertion to coda's Objects

Description

The functions convert MCMC traces (simulated using run.tfr.mcmc) into objects that can be used with the coda package.

Usage

coda.list.mcmc(mcmc = NULL, country = NULL, chain.ids = NULL, 
    sim.dir = file.path(getwd(), "bayesTFR.output"), 
    par.names = tfr.parameter.names(), 
    par.names.cs = tfr.parameter.names.cs(), 
    rm.const.pars = FALSE, burnin = 0, 
    low.memory = FALSE, ...)
	
## S3 method for class 'bayesTFR.mcmc':
coda.mcmc(mcmc, country = NULL, 
    par.names = tfr.parameter.names(), 
    par.names.cs = tfr.parameter.names.cs(), 
    burnin = 0, thin = 1, ...)

Arguments

Value

The function coda.list.mcmc returns an object of class mcmc.list. The function coda.mcmc returns an object of class mcmc, both defined in the coda package.

Rdversion

1.1