Learn R Programming

bayesTFR (version 1.2-0)

get.tfr.mcmc: Accessing MCMC Results

Description

The function get.tfr.mcmc retrieves results of an MCMC simulation and creates an object of class bayesTFR.mcmc.set. Function has.tfr.mcmc checks the existence of such results. Function tfr.mcmc extracts a single chain and tfr.mcmc.list extracts several or all chains from the simulation results.

Usage

get.tfr.mcmc(sim.dir = file.path(getwd(), "bayesTFR.output"), 
    chain.ids = NULL, low.memory = TRUE, 
    burnin = 0, verbose = FALSE)

has.tfr.mcmc(sim.dir)

tfr.mcmc(mcmc.set, chain.id)

tfr.mcmc.list(mcmc.set, chain.ids=NULL)

Arguments

Value

get.tfr.mcmc returns an object of class bayesTFR.mcmc.set. has.tfr.mcmc returns a logical value. tfr.mcmc returns an object of class bayesTFR.mcmc, and tfr.mcmc.list returns a list of bayesTFR.mcmc objects.

Rdversion

1.1

See Also

bayesTFR.mcmc.set

Examples

Run this code
sim.dir <- file.path(.find.package("bayesTFR"), "ex-data", 'bayesTFR.output')
m <- get.tfr.mcmc(sim.dir)
summary(m)

# summary of the single chains
for(mc in tfr.mcmc.list(m)) print(summary(mc))

Run the code above in your browser using DataLab