Learn R Programming

bayesTFR (version 5.0-0)

summary.bayesTFR.mcmc.set: Summary Statistics for TFR Markov Chain Monte Carlo Chains

Description

Summary of an object bayesTFR.mcmc.set or bayesTFR.mcmc, computed via run.tfr.mcmc or run.tfr3.mcmc. It can be obtained either for all countries or for a specific country, and either for all parameters or for specific parameters. The function uses the summary.mcmc function of the coda package.

Usage

## S3 method for class 'bayesTFR.mcmc.set':
summary(object, country = NULL, chain.id = NULL,
    par.names = NULL, par.names.cs = NULL, meta.only = FALSE, 
    thin = 1, burnin = 0, \dots)
	
## S3 method for class 'bayesTFR.mcmc':
summary(object, country = NULL, par.names = NULL, par.names.cs = NULL, 
    thin = 1, burnin = 0, \dots)

Arguments

Rdversion

1.1

See Also

bayesTFR.mcmc.set, summary.mcmc

Examples

Run this code
sim.dir <- file.path(find.package("bayesTFR"), "ex-data", "bayesTFR.output")
m <- get.tfr.mcmc(sim.dir)
summary(m, country="Czech Republic", burnin=15)

Run the code above in your browser using DataLab