tfr.diagnose runs convergence diagnostics of existing TFR MCMCs, using the raftery.diag function from the has.mcmc.converged checks if the existing diagnostics converged.tfr.diagnose(sim.dir, thin=80, burnin = 2000, express = FALSE,
country.sampling.prop = NULL, keep.thin.mcmc=FALSE, verbose = TRUE)
has.mcmc.converged(diag)has.mcmc.converged returns a logical value determining if there is convergence or not.
tfr.diagnose returns an object of class bayesTFR.convergence with components:result that correspond to country-independent paramters. These rows are groupped at the beginning of the table.tfr.raftery.diag processed on country-independent parameters.tfr.raftery.diag processed on country-specific parameters.bayesTFR.mcmc.set that corresponds to the original set of MCMCs on which the diagnostics was run.keep.thin.mcmc is TRUE, it is an object of class bayesTFR.mcmc.set that corresponds to the thinned mcmc set on which the diagnostics was run, otherwise NULL.express.used - number of countries used in this diagnostics, and total - number of countries that this mcmc.set object was estimated on.tfr.raftery.diag function separately for country-independent parameters and for country-specific parameters. It results in two possible states: red, i.e. it did not converge, and green, i.e. it converged.
The resulting object is stored in get.tfr.convergence.tfr.raftery.diag, raftery.diag, summary.bayesTFR.convergence, get.tfr.convergence, create.thinned.tfr.mcmc