Learn R Programming

bayesTFR (version 2.1-0)

tfr.gelman.diag: Gelman Diagnostics for Multiple Burnins

Description

The function computes the Gelman diagnostics for given parameters in the interval $[t_0, t_1]$ where either $t_0$ or $t_1$ can be moved by a given step.

Usage

tfr.gelman.diag(sim.dir = file.path(getwd(), "bayesTFR.output"), 
    t.start = 0, t.end = NULL, step = NULL, move.t0 = TRUE, 
    par.names = tfr.parameter.names(trans = TRUE), 
    par.names.cs = tfr.parameter.names.cs(trans = TRUE), 
    file.name = paste("gelman.diag.", 
        ifelse(move.t0, "t0", "t1"), ".txt", sep = ""), 
    append = FALSE, verbose = TRUE)

Arguments

Value

Table read from from file.name.

Rdversion

1.1

Details

If move.t0 is TRUE, the Gelman diagnostics is computed in the interval [t_0(i), N] where t_0(i)=t.start+(i-1)*step, i=1,2,..., t_0(i) <= t.end<="" code="">. If move.t0 is FALSE, the Gelman diagnostics is computed in the interval [0, t_1(i)] where t_1(i)=i*step, i=1,2,..., t.start <= t_1(i)="" <="t.end.

The first column of the resulting file is called t0, if move.t0 is TRUE, or t1, if move.t0 is FALSE, and it contains values of the moving $t$. The remaining columns contain the Gelman diagnostics for each parameter.

Results can be plotted using tfr.plot.gelman.

See Also

tfr.plot.gelman