tfr.parameter.names returns names of the country-independent parameters.
tfr.parameter.names.cs returns names of the country-specific parameters.
tfr.parameter.names.extended returns names of all country-independent parameters, including the transformed parameters. Parameters alpha, delta, alphat, anddeltat are in their extended format with the postfix _1, _2 and _3.
tfr.parameter.names.cs.extended returns names of all country-specific parameters, including the transformed parameters. Parameters gamma andgammat are in their extended format with the postfix _1, _2 and _3.