Learn R Programming

bayesTFR (version 4.2-0)

tfr.predict.extra: Generating Posterior Trajectories of the Total Fertility Rate for Specific Countries or Regions

Description

Using the posterior parameter samples the function generates posterior trajectories of the total fertility rate for given countries or regions. It is intended to be used after running run.tfr.mcmc.extra, but it can be also used for purposes of testing specific settings on one or a few countries.

Usage

tfr.predict.extra(sim.dir = file.path(getwd(), 'bayesTFR.output'), 
    prediction.dir = sim.dir, countries = NULL, 
    save.as.ascii = 1000, verbose = TRUE)

Arguments

Value

Updated object of class bayesTFR.prediction.

Rdversion

1.1

Details

In order to use this function, a prediction object must exist, i.e. the function tfr.predict must have been processed prior to using this function.

Trajectories for given countries or regions are generated and stored in binary format along with other countries (in prediction_dir). The existing prediction object is updated and stored in the same directory. If save.as.ascii is larger than zero, trajectories of ALL countries are converted to an ascii format.

See Also

tfr.predict