data(UN2010)data(UN2008)
data(UN2010_supplemental)
UN2008 and UN2010, respectively, must be included in the data set of locations, i.e. WPP2008_LOCATIONS and WPP2010_LOCATIONS, respectively. The the corresponding data set pair is matched using the column country_code.Regarding the time columns, only those are necessary that correspond to an earlier or equal time point than the value of the argument present.year passed to the function run.tfr.mcmc. Thus, if present.year=2009, all columns after 2005-2010 are not used.
Optionally, the data set can contain a column called last.observed containing the year of the last observation for each country. In such a case, the code would ignore any data after that time point. Furthermore, the function tfr.predict fills in the missing values using the median of the BHM procedure (stored in tfr_matrix_reconstructed of the bayesTFR.prediction object). For last.observed values that are below a middle year of a time interval $[t_i, t_{i+1}]$ (computed as $t_i+3$) the last valid data point is the time interval $[t_{i-1}, t_i]$, whereas for values larger equal a middle year, the data point in $[t_i, t_{i+1}]$ is valid.
The package contains also a data set called country_code (see description of the argument my.tfr.file in run.tfr.mcmc).