Learn R Programming

bayesTFR (version 4.1-2)

UN_variants: Dataset with UN-specific Coding of Variants

Description

Dataset used by the UN for coding variants. It also includes variants for the lower and upper bounds of the 80 and 95% probability intervals, respectively, resulting from the Bayesian hierarchical model. The dataset is stored in a TAB-separated ASCII file called UN_variants.txt.

Usage

data(UN_variants)

Arguments

Rdversion

1.1

docType

data

source

Data provided by the United Nations Population Division

Examples

Run this code
data(UN_variants)
str(UN_variants)

Run the code above in your browser using DataLab