bayesTFR.mcmc.meta used by all chains of the same MCMC simulation.
It contains information that is common to all chains. It is part of a bayesTFR.mcmc.set object.bayesTFR.mcmc.meta object contains components U.width, U.c.low, U.up,
a.width, a.low, a.up,
b.width, b.low, b.up,
const.width, const.low, const.up,
S.width, S.low, S.up,
sigma0.width, sigma0.low, sigma0.up,
sigma0.min,
mean.eps.tau0, sd.eps.tau0, nu.tau0,
d.low, d.up,
Triangle4.0, delta4.0, nu4,
Triangle_c4.low, Triangle_c4.up,
Triangle_c4.trans.width,
chi0, nu.psi0, psi0, d.trans.width,
dl.p1, dl.p2,
nu.delta0, delta0, alpha0.p, start.year, present.year, wpp.year, buffer.size, auto.conf. Their meaning and value are the same as the input arguments
to the run.tfr.mcmc function. Furthermore, it contains components:T_end below), $n$ is number of countries (see nr_countries below). The first $n_e$ columns correspond to countries included in the MCMC estimation (see nr_countries_estimation below), where $n_e <= n$.<="" description="">tfr_matrix_all, but it has NA values before and after country's fertility transition.tfr_matrix, but it has NA values for years where no historical data is available.nr_countries.start.year.present.year is equal to tau_c.tau_c=-1.tfr_matrix).tau_c and 1 for each country. Thus, it is a row index of the tfr_matrix where the fertility decline starts.tfr_matrix).T_end but country specific.nr_countries. These are:
name - Region name for each country.
code - Region code for each country.
area_name - Area name for each country.
area_code - Area code for each country.
country_name - Array of country names.
country_code - Array of country codes.
Any country indices in the bayesTFR.mcmc.meta object are derived from this component.bayesTFR.mcmc.set object.run.tfr.mcmc, get.tfr.mcmcsim.dir <- file.path(.find.package("bayesTFR"), "ex-data", 'bayesTFR.output')
m <- get.tfr.mcmc(sim.dir)
summary(m, meta.only = TRUE)
names(m$meta)Run the code above in your browser using DataLab