Learn R Programming

bayesTFR (version 4.2-0)

bayesTFR.mcmc.meta: MCMC Simulation Meta Object

Description

Simulation meta object bayesTFR.mcmc.meta used by all chains of the same MCMC simulation. It contains information that is common to all chains. It is part of a bayesTFR.mcmc.set object.

Arguments

Value

A bayesTFR.mcmc.meta object contains various components that correspond to the input arguments of the run.tfr.mcmc and run.tfr3.mcmc functions. Furthermore, it contains components:nr.chainsNumber of MCMC chains.phaseValue 2 or 3, depending which Phase the object belongs to.output.dirDirectory for storing simulation output.

Rdversion

1.1

Details

The object is in standard cases not to be manipulated by itself, but rather as part of a bayesTFR.mcmc.set object.

See Also

run.tfr.mcmc, get.tfr.mcmc, run.tfr3.mcmc, get.tfr3.mcmc

Examples

Run this code
sim.dir <- file.path(find.package("bayesTFR"), "ex-data", "bayesTFR.output")
m <- get.tfr.mcmc(sim.dir)
summary(m, meta.only = TRUE)
names(m$meta)

Run the code above in your browser using DataLab