Learn R Programming

bayesTFR (version 4.2-0)

coda.list.mcmc: Convertion to coda's Objects

Description

The functions convert MCMC traces (simulated using run.tfr.mcmc and run.tfr3.mcmc) into objects that can be used with the coda package.

Usage

coda.list.mcmc(mcmc = NULL, country = NULL, chain.ids = NULL, 
    sim.dir = file.path(getwd(), "bayesTFR.output"), 
    par.names = tfr.parameter.names(), 
    par.names.cs = tfr.parameter.names.cs(), 
    rm.const.pars = FALSE, burnin = 0, 
    low.memory = FALSE, ...)
    
coda.list.mcmc3(mcmc = NULL, country = NULL, chain.ids = NULL, 
    sim.dir = file.path(getwd(), "bayesTFR.output"), 
    par.names = tfr3.parameter.names(), 
    par.names.cs = tfr3.parameter.names.cs(), 
    burnin = 0, low.memory = FALSE, ...)
	
## S3 method for class 'bayesTFR.mcmc':
coda.mcmc(mcmc, country = NULL, 
    par.names = NULL, par.names.cs = NULL, 
    burnin = 0, thin = 1, \dots)

Arguments

Value

The function coda.list.mcmc and coda.list.mcmc3 return an object of class mcmc.list. The function coda.mcmc returns an object of class mcmc, both defined in the coda package.

Rdversion

1.1

Details

Function coda.list.mcmc is for accessing all chains of phase II MCMCs; Function coda.list.mcmc3 is for accessing all chains of phase III MCMCs.