Learn R Programming

bayesTFR (version 4.2-0)

get.country.object: Accessing Country Information

Description

Function get.country.object returns an object containing country name, code and index. Functions get.countries.table return a data frame containing codes and names of all countries.

Usage

get.country.object(country, meta = NULL, country.table = NULL, index = FALSE)
## S3 method for class 'bayesTFR.mcmc.set':
get.countries.table(object, \dots)
## S3 method for class 'bayesTFR.prediction':
get.countries.table(object, \dots)

Arguments

Value

Function get.country.object returns a list with components:nameCountry namecodeCountry codeindexCountry indexFunction get.countries.table return a data frame with columns code and name.

Details

Given partial information about a country (i.e. having either name or code or index), the function get.country.object returns an object containing all three pieces of information. Only countries are considered that are included in the simulations and predictions. Country index is an internal index used in various components of a bayesTFR.mcmc.meta object.

See Also

country.names

Examples

Run this code
sim.dir <- file.path(find.package("bayesTFR"), "ex-data", "bayesTFR.output")
m <- get.tfr.mcmc(sim.dir)
# all four calls should give the same answer
get.country.object('China', m$meta)
get.country.object(156, m$meta)
get.country.object(56, m$meta, index=TRUE)
get.country.object(156, NULL, country.table=get.countries.table(m))

Run the code above in your browser using DataLab