The function get.tfr.mcmc retrieves results of an MCMC simulation and creates an object of class bayesTFR.mcmc.set. Function has.tfr.mcmc checks the existence of such results. Function tfr.mcmc extracts a single chain and tfr.mcmc.list extracts several or all chains from the simulation results.
get.tfr.mcmc returns an object of class bayesTFR.mcmc.set. has.tfr.mcmc returns a logical value. tfr.mcmc returns an object of class bayesTFR.mcmc, and tfr.mcmc.list returns a list of bayesTFR.mcmc objects.
sim.dir <- file.path(.find.package("bayesTFR"), "ex-data", 'bayesTFR.output')
m <- get.tfr.mcmc(sim.dir)
summary(m)
# summary of the single chainsfor(mc in tfr.mcmc.list(m)) print(summary(mc))