Function get.tfr.prediction retrieves results of a prediction and creates an object of class bayesTFR.prediction. Function has.tfr.prediction checks an existence of such results.
Function has.tfr.prediction returns a logical indicating if a prediction exists for the given mcmc.
Function get.tfr.prediction returns an
object of class bayesTFR.prediction.
Rdversion
1.1
Details
If mcmc is not NULL, the search directory is set to mcmc$meta$output.dir. This approach assumes that the prediction was stored in the same directory as the MCMC simulation, i.e. the output.dir argument of the tfr.predict function was set to NULL. If it is not the case, the argument mcmc.dir should be used.