run.tfr.mcmc(nr.chains = 3, iter = 62000,
output.dir = file.path(getwd(), "bayesTFR.output"),
thin = 1, replace.output = FALSE,
start.year = 1750, present.year = 2010, wpp.year = 2012,
my.tfr.file = NULL, buffer.size = 100,
U.c.low = 5.5, U.up = 8.8, U.width = 3,
mean.eps.tau0 = -0.25, sd.eps.tau0 = 0.4, nu.tau0 = 2,
Triangle_c4.low = 1, Triangle_c4.up = 2.5,
Triangle_c4.trans.width = 2,
Triangle4.0 = 0.3, delta4.0 = 0.8, nu4 = 2,
S.low = 3.5, S.up = 6.5, S.width = 0.5,
a.low = 0, a.up = 0.2, a.width = 0.02,
b.low = a.low, b.up = a.up, b.width = 0.02,
sigma0.low = 0.01, sigma0.up = 0.6, sigma0.width = 0.1,
sigma0.min = 0.001,
const.low = 0.8, const.up = 2, const.width = 0.3,
d.low = 0.05, d.up = 0.5, d.trans.width = 1,
chi0 = -1.5, psi0 = 0.6, nu.psi0 = 2,
alpha0.p = c(-1, 0.5, 1.5), delta0 = 1, nu.delta0 = 2,
dl.p1 = 9, dl.p2 = 9,
S.ini = NULL, a.ini = NULL, b.ini = NULL, sigma0.ini = NULL,
Triangle_c4.ini = NULL, const.ini = NULL, gamma.ini = 1,
proposal_cov_gammas = NULL,
seed = NULL, parallel = FALSE, nr.nodes = nr.chains,
save.all.parameters = FALSE, compression.type = 'None',
auto.conf = list(max.loops=5, iter=62000, iter.incr=10000,
nr.chains=3, thin=80, burnin=2000),
verbose = FALSE, verbose.iter = 10, ...)
continue.tfr.mcmc(iter, chain.ids=NULL,
output.dir=file.path(getwd(), "bayesTFR.output"),
parallel = FALSE, nr.nodes = NULL, auto.conf = NULL,
verbose=FALSE, verbose.iter = 10, ...)bayesTFR.mcmc.set which is a list with two components:bayesTFR.mcmc.meta.bayesTFR.mcmc, one for each MCMC.run.tfr.mcmc creates an object of class bayesTFR.mcmc.meta and stores it in output.dir. It launches nr.chains MCMCs, either sequentially or in parallel. Parameter traces of each chain are stored as (possibly compressed) ASCII files in a subdirectory of output.dir, called mcx where x is the identifier of that chain. There is one file per parameter, named after the parameter with the suffix compression.type is given. Country-specific parameters ($U, d, \gamma$) have the suffix _cy where y is the country code. In addition to the trace files, each mcx directory contains the object bayesTFR.mcmc in binary format. All chain-specific files are written into disk after the first, last and each buffer.size-th iteration.
Using the function continue.tfr.mcmc one can continue simulating an existing MCMCs by iter iterations for either all or selected chains.The function loads observed data (further denoted as WPP dataset) from the tfr and tfr_supplemental datasets in a wpp.year. It is then merged with the include dataset that corresponds to the same wpp.year. The argument my.tfr.file can be used to overwrite those default data. Such a file can include a subset of countries contained in the WPP dataset, as well as a set of new countries. In the former case,
the function replaces the corresponding country data from the WPP dataset by values in this file. Only columns are replaced that match column names of the WPP dataset, and in addition, columns UNlocations). In addition, their corresponding include_code must be set to 2. If the column my.tfr.file, its value overwrites the default include code, unless is -1.
For simulation of the hyperparameters of the Bayesian hierarchical model, all countries are used that are included in the WPP dataset, possibly complemented by the my.tfr.file, that have include_code equal to 2. The hyperparameters are used to simulate country-specific parameters, which is done for all countries with include_code equal 1 or 2. The following values of include_code in my.tfr.file are recognized: -1 (do not overwrite the default include code), 0 (ignore), 1 (include in prediction but not estimation), 2 (include in both, estimation and prediction). Thus, the set of countries included in the estimation and prediction can be fully user-specific.
Optionally, my.tfr.file can contain a column called last.observed containing the year of the last observation for each country. In such a case, the code would ignore any data after that time point. Furthermore, the function tfr.predict fills in the missing values using the median of the BHM procedure (stored in tfr_matrix_reconstructed of the bayesTFR.prediction object). For last.observed values that are below a middle year of a time interval $[t_i, t_{i+1}]$ (computed as $t_i+3$) the last valid data point is the time interval $[t_{i-1}, t_i]$, whereas for values larger equal a middle year, the data point in $[t_i, t_{i+1}]$ is valid.
The package contains a dataset called my.tfr.file.
get.tfr.mcmc, summary.bayesTFR.mcmc.set.m <- run.tfr.mcmc(nr.chains=1, iter=5, verbose=TRUE)
summary(m)
m <- continue.tfr.mcmc(iter=5, verbose=TRUE)
summary(m)Run the code above in your browser using DataLab