summary.bayesTFR.mcmc.set: Summary Statistics for TFR Markov Chain Monte Carlo Chains
Description
Summary of an object bayesTFR.mcmc.set or bayesTFR.mcmc, computed via run.tfr.mcmc or run.tfr3.mcmc. It can be obtained either for all countries or for a specific country, and either for all parameters or for specific parameters. The function uses the summary.mcmc function of the coda package.
Usage
## S3 method for class 'bayesTFR.mcmc.set':
summary(object, country = NULL, chain.id = NULL,
par.names = NULL, par.names.cs = NULL, meta.only = FALSE,
thin = 1, burnin = 0, \dots)
## S3 method for class 'bayesTFR.mcmc':
summary(object, country = NULL, par.names = NULL, par.names.cs = NULL,
thin = 1, burnin = 0, \dots)