Learn R Programming

bayesTFR (version 4.2-0)

tfr.dl.coverage: Goodness of Fit of the Double Logistic Function

Description

The function computes coverage, i.e. the ratio of observed data fitted within the given probability intervals of the predictive posterior distribution of the double logistic function, as well as the root mean square error and mean absolute error of the simulation.

Usage

tfr.dl.coverage(sim.dir, pi = c(80, 90, 95), burnin = 2000, verbose = TRUE)

Arguments

Value

List with the following components:total.coverageVector of the coverage, one element per probability interval. For each pi, it is the ratio of the number of observed data points that fall within the probability interval of the posterior distribution over the total number of data points, i.e. TFR for all countries and historical time periods.time.coverageMatrix corresponding to the coverage computed per time period. (Rows correspond to probability intervals, columns correspond to time.) It is derived like total.coverage except that both, the nominator and denominator, contain only data points belonging to the corresponding time period.country.coverageMatrix corresponding to the coverage computed per country. (Rows correspond to probability intervals, columns correspond to countries.) It is derived like total.coverage except that both, the nominator and denominator, contain only data points belonging to the corresponding country.total.rmseRoot mean square error as $\sqrt{(1/n\sum(x-m)^2)}$ where $x$ are observed data points, $m$ is the mean of the posterior distribution and $n$ is the number of data points. Here the sum is taken over all countries and historical time periods.time.rmseLike total.rmse except that each time period is considered separately.country.rmseLike total.rmse except that each country is considered separately.total.maeMean absolute error as $1/n\sum|x-m|$ where $x$ are observed data points, $m$ is the median of the posterior distribution and $n$ is the number of data points. Here the sum is taken over all countries and historical time periods.time.maeLike total.mae except that each time period is considered separately.country.maeLike total.mae except that each country is considered separately.pred.cdf$T \times C$ matrix (with $T$ being the number of time periods and $C$ being the number of countries), containing the predictive CDF of the observation, i.e. the quantile of each data point within the predictive posterior distribution.n0-1 $T \times C$ matrix indicating if the corresponding data point was included in the goodness of fit computation. Zeros indicate missing historical values.

See Also

DLcurve.plot

Examples

Run this code
sim.dir <- file.path(find.package("bayesTFR"), "ex-data", "bayesTFR.output")
tfr <- get.tfr.mcmc(sim.dir)
# Note that this simulation is a toy example and thus has not converged.
gof <- tfr.dl.coverage(sim.dir)
gof$time.coverage
DLcurve.plot(tfr, country=608, predictive.distr=TRUE, pi=c(80, 90, 95))

Run the code above in your browser using DataLab