tfr.parameter.names returns names of the country-independent Phase II parameters.
tfr.parameter.names.cs returns names of the country-specific Phase II parameters.
tfr.parameter.names.extended returns names of all country-independent Phase II parameters, including the transformed parameters. Parameters alpha, delta, alphat, anddeltat are in their extended format with the postfix _1, _2 and _3.
tfr.parameter.names.cs.extended returns names of all country-specific Phase II parameters, including the transformed parameters. Parameters gamma andgammat are in their extended format with the postfix _1, _2 and _3.
tfr3.parameter.names returns names of the country-independent Phase III parameters.
tfr3.parameter.names.cs returns names of the country-specific Phase III parameters.