run.tfr.mcmc.extra, but it can be also used for purposes of testing specific settings on one or a few countries.tfr.predict.extra(sim.dir = file.path(getwd(), 'bayesTFR.output'),
prediction.dir = sim.dir, countries = NULL,
save.as.ascii = 1000, verbose = TRUE)bayesTFR.prediction.tfr.predict must have been processed prior to using this function.Trajectories for given countries or regions are generated and stored in binary format along with other countries (in prediction_dir). The existing prediction object is updated and stored in the same directory. If save.as.ascii is larger than zero, trajectories of ALL countries are converted to an ascii format.
tfr.predict