tfr.raftery.diag(mcmc = NULL,
sim.dir = file.path(getwd(), "bayesTFR.output"),
burnin = 0, country = NULL,
par.names = tfr.parameter.names(trans = TRUE),
par.names.cs = tfr.parameter.names.cs(trans=TRUE),
country.sampling.prop = 1, verbose=TRUE, ...)N, containing the burnin values (processed as described in Details).not.converged.parameters. The parameters included are those for which the computed value of Raftery diagnostics $N$ is larger than the number of finished iterations in the corresponding chain.N.country.indep, but here the country-specific parameters are considered.used (number of countries used in this diagnostics) and total (number of countries that this mcmc object was estimated on).raftery.diag with r=0.0125, q=0.025 and q=0.975. Values of $N$ and burnin are averaged over chains. For each country-specific parameter, the 95%-quantile over all included countries of such averaged values is taken.