Learn R Programming

bayesTFR (version 4.2-0)

tfr.raftery.diag: Raftery Diagnostics for Parameters of the Total Fertility Rate

Description

The functions compute the Raftery diagnostics for each parameter of MCMCs of phase II (tfr.raftery.diag) and phase III (tfr3.raftery.diag), taking median over all chains.

Usage

tfr.raftery.diag(mcmc = NULL, 
    sim.dir = file.path(getwd(), "bayesTFR.output"), 
    burnin = 0, country = NULL,
    par.names = tfr.parameter.names(trans = TRUE), 
    par.names.cs = tfr.parameter.names.cs(trans = TRUE, back.trans = FALSE),
    country.sampling.prop = 1, verbose=TRUE, ...)

tfr3.raftery.diag(mcmc = NULL, sim.dir = file.path(getwd(), "bayesTFR.output"), burnin = 0, country = NULL, par.names = tfr3.parameter.names(), par.names.cs = tfr3.parameter.names.cs(), country.sampling.prop = 1, verbose=TRUE, ...)

Arguments

Value

List with the components:Nmedian2-d array of $N$ values (processed as described in Details) with two rows: first corresponding to q=0.025, second corresponding to q=0.975. Each column corresponds to one parameter.burnin2-d array of the same structure as Nmedian, containing the burnin values (processed as described in Details).not.converged.parametersList with two elements, each of which is a data frame containing columns parameter.name, chain.id, and N. These are parameters for which the computed value of Raftery diagnostics $N$ is larger than the total number of finished iterations summed over all chains. The first element of the list corresponds to q=0.025, second corresponds to q=0.975.not.converged.inchain.parametersList of the same structure as not.converged.parameters. The parameters included are those for which the computed value of Raftery diagnostics $N$ is larger than the number of finished iterations in the corresponding chain.N.country.indepData frame containing columns parameter.name, chain.id, N0.025, and N0.975. Each row gives $N$ computed with the two different $q$ for each country-independent parameter and chain.N.country.specThe same as N.country.indep, but here the country-specific parameters are considered.Nmedian.country.spec2-d array of $N$ values for country-specific parameters containing medians over chains.thin.indList with elements '0.025', '0.975' and median. The first two elements are matrices with one row per chain and one column per parameter. They contain values of thin that makes the MCMC independent, for q=0.025 and q=0.975, respectively. The median element is of the same structure as Nmedian, containing medians ove rows in the two matrices in this list.nr.countriesVector with elements used (number of countries used in this diagnostics) and total (number of countries that this mcmc object was estimated on).

Rdversion

1.1

Details

The Raftery diagnostics is computed for each parameter, using coda's raftery.diag with r=0.0125, q=0.025 and q=0.975. Values of $N$ and burnin are taken as the median over chains. For each country-specific parameter, the maximum over all included countries of such medians is taken.

See Also

raftery.diag