tfr.raftery.diag) and phase III (tfr3.raftery.diag), taking median over all chains.tfr.raftery.diag(mcmc = NULL,
sim.dir = file.path(getwd(), "bayesTFR.output"),
burnin = 0, country = NULL,
par.names = tfr.parameter.names(trans = TRUE),
par.names.cs = tfr.parameter.names.cs(trans = TRUE, back.trans = FALSE),
country.sampling.prop = 1, verbose=TRUE, ...)tfr3.raftery.diag(mcmc = NULL,
sim.dir = file.path(getwd(), "bayesTFR.output"),
burnin = 0, country = NULL,
par.names = tfr3.parameter.names(),
par.names.cs = tfr3.parameter.names.cs(),
country.sampling.prop = 1, verbose=TRUE, ...)
Nmedian, containing the burnin values (processed as described in Details).not.converged.parameters. The parameters included are those for which the computed value of Raftery diagnostics $N$ is larger than the number of finished iterations in the corresponding chain.N.country.indep, but here the country-specific parameters are considered.median. The first two elements are matrices with one row per chain and one column per parameter. They contain values of thin that makes the MCMC independent, for q=0.025 and q=0.975, respectively. The median element is of the same structure as Nmedian, containing medians ove rows in the two matrices in this list.used (number of countries used in this diagnostics) and total (number of countries that this mcmc object was estimated on).raftery.diag with r=0.0125, q=0.025 and q=0.975. Values of $N$ and burnin are taken as the median over chains. For each country-specific parameter, the maximum over all included countries of such medians is taken.raftery.diag